<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-oc',
'0_langue' => 'Nissart [oc_ni]',
'0_liste' => 'spip-oc@rezo.net',
'0_mainteneur' => 'S&eacute;bastien Donato&nbsp;: sebastien@donato.fr',

// A
'access_interface_graphique' => 'Tornar &agrave; l\'interfa&ccedil;a grafica completa',
'access_mode_texte' => 'Affichar l\'interfa&ccedil;a textuala simplificada', # essai commentaire
'admin_debug' => 'debug',
'admin_modifier_article' => 'Modificar aquel article',
'admin_modifier_auteur' => 'Modificar aquel autor',
'admin_modifier_breve' => 'Modificar aquela br&egrave;va',
'admin_modifier_mot' => 'Modificar aqueu m&ograve;t clau',
'admin_modifier_rubrique' => 'Modificar aquela rubrica',
'admin_recalculer' => 'Tornar calcular aquesta p&agrave;gina',
'afficher_trad' => 'afichar li reviradas',
'alerte_maj_impossible' => '<b>Al&egrave;rta!</b> Es impossible d\'actualisar la basa SQL v&egrave;rs la version @version@; bessai li a un problema relatiu au drech de modificar la basa de donadas. Vorgatz contactar lo voastre aubergador.',
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute; par ailleurs. La valeur actuelle est&nbsp;:', # MODIF
'analyse_xml' => 'Analisa XML',
'annuler' => 'Anular',
'antispam_champ_vide' => 'Vorgatz laissar aquel camp vu&egrave;i:',
'articles_recents' => 'Lu articles mai recents',
'avis_archive_incorrect' => 'lo fichier arquiu es pas un fichier SPIP',
'avis_archive_invalide' => 'lo fichier arquiu es pas valid',
'avis_attention' => 'DAIDA&nbsp;!',
'avis_champ_incorrect_type_objet' => 'Nom de camp incorrecte @name@ per object de tipe',
'avis_colonne_inexistante' => 'La col&ograve;na @col@ existisse pas',
'avis_echec_syndication_01' => 'La sindicacion a pas capitat: lo backend indicat es indeschifrable &ograve; prepaua minga d\'article.',
'avis_echec_syndication_02' => 'La sindicacion a pas capitat: impossible d\'accedir au backend d\'aqueu sit.',
'avis_erreur' => 'Error: veire &ccedil;ai sota',
'avis_erreur_connexion' => 'Error de connexion',
'avis_erreur_cookie' => 'probl&egrave;ma de cookie',
'avis_erreur_fonction_contexte' => 'Error de programacion. Cau pas apelar aquela foncion dins aqueu cont&egrave;xt.',
'avis_erreur_mysql' => 'Error SQL ',
'avis_erreur_sauvegarde' => 'Error dins la sauvagarda (@type@ @id_objet@) ! ',
'avis_erreur_visiteur' => 'Probl&egrave;ma per acc&egrave;dre &agrave; l\'espaci privat',

// B
'barre_a_accent_grave' => 'Inserir una A accent gr&egrave;u majuscula',
'barre_aide' => 'Utilisar li escorchas tipografiqui per enriquir la voastra compaginacion',
'barre_e_accent_aigu' => 'Inserir una E accent agut majuscula',
'barre_eo' => 'Inserir una E dins l\'O',
'barre_eo_maj' => 'Inserir una E dins l\'O majuscula',
'barre_euro' => 'Inserir lo simb&ograve;l &euro;',
'barre_gras' => 'Metre en {{gras}}',
'barre_guillemets' => 'Enrodar m&eacute; de &laquo; verguetas francesi &raquo;',
'barre_guillemets_simples' => 'Enrodar m&eacute; de &#132;verguetas&#147;',
'barre_intertitre' => 'Transformar en {{{intertitre}}}',
'barre_italic' => 'Metre en {italics}',
'barre_lien' => 'Transformar en [ligam ipert&egrave;xt->http://...]',
'barre_lien_input' => 'Vorgatz indicar l\'adre&ccedil;a dau voastre ligam (pod&egrave;tz indicar una adre&ccedil;a web sota la forma http://www.lomieusit.com &ograve; simplament indicar lo n&uacute;mero d\'un article d\'aqueu sit).',
'barre_note' => 'Transformar en [[N&ograve;ta de bas de p&agrave;gina]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
'barre_quote' => '<quote>Citar un messatge</quote>',
'bouton_ajouter_document' => 'Ajustar un document',
'bouton_ajouter_image' => 'Ajustar un imatge',
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
'bouton_changer' => 'Cambiar',
'bouton_chercher' => 'Cercar',
'bouton_choisir' => 'Chausir',
'bouton_download' => 'Telecargar',
'bouton_enregistrer' => 'Registrar',
'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la messatgeria interna',
'bouton_radio_envoi_annonces' => 'Mandar lu anoncis editoriaus',
'bouton_radio_non_envoi_annonces' => 'Mandar pas d\'anoncis',
'bouton_radio_non_envoi_liste_nouveautes' => 'Mandar pas la ti&egrave;ra dei novetats',
'bouton_recharger_page' => 'tornar cargar aquela p&agrave;gina',
'bouton_telecharger' => 'Descargar',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'apr&egrave;s-miegjorn',
'cal_jour_entier' => 'jorn enti&eacute;',
'cal_matin' => 'matin',
'cal_par_jour' => 'calendier per jorn',
'cal_par_mois' => 'calendier per mes',
'cal_par_semaine' => 'calendier per setmana',
'choix_couleur_interface' => 'color ',
'choix_interface' => 'chausida de l\'interfa&ccedil;a',
'colonne' => 'Colomna',
'confirm_changer_statut' => 'Atencion, av&egrave;tz demandat de cambiar l\'estatut d\'aquel element. Desiratz continuar? ',
'correcte' => 'corr&egrave;cte',

// D
'date_aujourdhui' => 'encu&egrave;i',
'date_avant_jc' => 'avans lo Crist',
'date_dans' => 'dins @delai@',
'date_de_mois_1' => '@j@ de genoier',
'date_de_mois_10' => '@j@ d\'oct&ograve;bre',
'date_de_mois_11' => '@j@ de novembre',
'date_de_mois_12' => '@j@ de decembre',
'date_de_mois_2' => '@j@ de febrier',
'date_de_mois_3' => '@j@ de mars',
'date_de_mois_4' => '@j@ d\'abriu',
'date_de_mois_5' => '@j@ de mai',
'date_de_mois_6' => '@j@ de junh',
'date_de_mois_7' => '@j@ de julhet',
'date_de_mois_8' => '@j@ d\'avost',
'date_de_mois_9' => '@j@ de setembre',
'date_demain' => 'deman',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ &agrave; @heure@',
'date_fmt_jour_mois' => 'lo @jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@ dau @annee@',
'date_fmt_mois_annee' => '@nommois@ dau @annee@',
'date_fmt_nomjour_date' => 'lo @nomjour@ @date@',
'date_heures' => 'oras',
'date_hier' => 'i&egrave;r',
'date_il_y_a' => 'fa @delai@',
'date_jnum1' => '1er',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'dim&eacute;negue',
'date_jour_1_abbr' => 'dmg.',
'date_jour_1_initiale' => 'dg.',
'date_jour_2' => 'diluns',
'date_jour_2_abbr' => 'dil.',
'date_jour_2_initiale' => 'dl.',
'date_jour_3' => 'dimars',
'date_jour_3_abbr' => 'dmr.',
'date_jour_3_initiale' => 'dm.',
'date_jour_4' => 'dim&egrave;cres',
'date_jour_4_abbr' => 'dmc.',
'date_jour_4_initiale' => 'dc.',
'date_jour_5' => 'dij&ograve;us',
'date_jour_5_abbr' => 'dij.',
'date_jour_5_initiale' => 'dj.',
'date_jour_6' => 'divendres',
'date_jour_6_abbr' => 'div.',
'date_jour_6_initiale' => 'dv.',
'date_jour_7' => 'dissabta',
'date_jour_7_abbr' => 'dis.',
'date_jour_7_initiale' => 'ds.',
'date_jours' => 'jorns',
'date_minutes' => 'minutas',
'date_mois' => 'm&egrave;s',
'date_mois_1' => 'genoier',
'date_mois_10' => 'oct&ograve;bre',
'date_mois_11' => 'novembre',
'date_mois_12' => 'decembre',
'date_mois_2' => 'febrier',
'date_mois_3' => 'mars',
'date_mois_4' => 'abriu',
'date_mois_5' => 'mai',
'date_mois_6' => 'junh',
'date_mois_7' => 'julhet',
'date_mois_8' => 'avost',
'date_mois_9' => 'setembre',
'date_saison_1' => 'inv&egrave;rn',
'date_saison_2' => 'prima',
'date_saison_3' => 'estiu',
'date_saison_4' => 'auton',
'date_secondes' => 'secondas',
'date_semaines' => 'setmanas',
'date_un_mois' => 'mes',
'date_une_heure' => 'ora',
'date_une_minute' => 'minuta',
'date_une_seconde' => 'seconda',
'date_une_semaine' => 'setmana',
'dirs_commencer' => 'per comen&ccedil;ar vertadierament l\'installacion',
'dirs_preliminaire' => 'Preliminari : <b>Reglar lu drechs d\'acc&egrave;s</b>',
'dirs_probleme_droits' => 'Probl&egrave;ma de drechs d\'acc&egrave;s',
'dirs_repertoires_absents' => '<p><b>Lu repert&ograve;ris seguents son pas estat trobats:</b></p><ul>@bad_dirs@.</ul>
  <p>Si p&ograve;u que vene d\'un problema de majusculas &ograve; minusculas mau mesi.
  Verificatz que li minusculas e majusculas d\'aquelu repert&ograve;ris correspoandon ben emb&eacute; cen qu\'es afichat
  &ccedil;ai sobre; s\'es pas lo cas, tornatz nommar lu repert&ograve;ris emb&eacute; lo voastre logiciau FTP per corregir l\'error.</p>
  <p>Un c&ograve;up qu\'auretz fach aqu&ograve;, podretz ',
'dirs_repertoires_suivants' => '<p><b>Lu repert&ograve;ris seguents son pas accessibles en escritura&nbsp;:</b></p><ul>@bad_dirs@.</ul>
  <p>Per adobar aqu&ograve;, utilisatz lo voastre client FTP per fin de reglar lu drechs d\'acc&egrave;s de cadun
  d\'aquelu repert&ograve;ris. Lo guida d\'installacion explica en detalh coma  proc&egrave;dre.</p>
  <p>Un c&ograve;up aquesta manipulacion facha, podretz ',
'double_occurrence' => 'Dobla ocurr&eacute;n&ccedil;a',

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Dimensions:',
'entree_titre_document' => 'Titre dau document:',
'entree_titre_image' => 'Titre de l\'imatge:',
'envoi_via_le_site' => 'Mandad&iacute;s m&eacute; lo biais dau sit web',
'erreur' => 'Error',
'erreur_balise_non_fermee' => 'darri&egrave;ra balisa non tapada :',
'erreur_texte' => 'error(s)',
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'Fichier @fichier@ introuvable',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Si&egrave;tz ja inscrich(a).',
'form_email_non_valide' => 'La voastra adre&ccedil;a e-mail es pas valida.',
'form_forum_access_refuse' => 'Pod&egrave;tz plus accedir &agrave;-n-aqueu sit.',
'form_forum_bonjour' => 'Boanjorn,',
'form_forum_email_deja_enregistre' => 'Aquela adre&ccedil;a e-mail es ja registrada, pod&egrave;tz doncas utilisar lo voastre m&ograve;t de santa Clara costumier.',
'form_forum_identifiant_mail' => 'Lo voastre nov&egrave;l identificant ven de v\'&egrave;stre mandat per e-mail.',
'form_forum_identifiants' => 'Identificants personaus',
'form_forum_indiquer_nom_email' => 'Indicatz aqu&iacute; lo voastre nom e la voastra adre&ccedil;a e-mail. Lo voastre identificant personau arribar&agrave; rapidament, per corrier electronic.',
'form_forum_login' => 'login :',
'form_forum_message_auto' => '(aqu&ograve;\'s un messatge automatic)',
'form_forum_pass' => 'm&ograve;t de santa Clara :',
'form_forum_probleme_mail' => 'Probl&egrave;ma d\'e-mail&nbsp;: si p&ograve;u pas mandar l\'identificant.',
'form_forum_voici1' => 'V&egrave;tz lu voastres identificants per poder participar &agrave; la vida
dau sit "@nom_site_spip@" (@adresse_site@) :',
'form_forum_voici2' => 'V&egrave;tz lu voastres identificants per prepauar d\'articles 
 sus lo sit "@nom_site_spip@" (@adresse_login@) :',
'form_indiquer_email' => 'Vorgatz indicar la voastra adre&ccedil;a e-mail.',
'form_indiquer_nom' => 'Vorgatz indicar lo voastre nom.',
'form_indiquer_nom_site' => 'Vorgatz indicar lo nom dau voastre sit.',
'form_pet_adresse_site' => 'Adre&ccedil;a dau voastre sit',
'form_pet_aucune_signature' => 'Minga de signatura correspoande &agrave;-n-aqueu c&ograve;de...',
'form_pet_confirmation' => 'Vorgatz confirmar la voastra signatura :',
'form_pet_deja_enregistre' => 'Aqueu sit es ja registrat',
'form_pet_deja_signe' => 'Av&egrave;tz ja signat aqueu t&egrave;xt.',
'form_pet_envoi_mail_confirmation' => 'A&uuml;ra recebretz un corrier electronic de confirmacion sus @email@. Per validar la voastra signatura, cau visitar l\'adre&ccedil;a web mencionada per aquest corrier.',
'form_pet_mail_confirmation' => 'Boanjorn,

Av&egrave;tz demandat de signar la peticion:
@titre@.

Av&egrave;tz fornit li informacions seguenti:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar la voastra signatura, basta vos connectar a
l\'adre&ccedil;a &ccedil;ai sota (dins lo cas contrari, la voastra demanda
ser&agrave; refudada) :

    @url@


Merc&eacute; de la voastra participacion
',
'form_pet_message_commentaire' => 'Un messatge, una remarca&nbsp;?',
'form_pet_nom_site2' => 'Nom dau voastre sit web',
'form_pet_probleme_liens' => 'Vorgatz tornar escriure lo voastre messatge en supprimant lu ligams ipert&egrave;xt.',
'form_pet_probleme_technique' => 'Probl&egrave;ma tecnic, li signaturas son tempor&agrave;riament arrestadi.',
'form_pet_signature_pasprise' => 'La voastra signatura es pas pilhada en c&ograve;mpte.',
'form_pet_signature_validee' => 'La voastra signatura es validada. Merc&eacute;&nbsp;!',
'form_pet_site_deja_enregistre' => 'Aqueu sit es ja registrat',
'form_pet_url_invalide' => 'L\'URL qu\'av&egrave;tz indicada es pas valida.',
'form_pet_votre_email' => 'La voastra adre&ccedil;a e-mail',
'form_pet_votre_nom' => 'Lo voastre nom &ograve; pseudonim',
'form_pet_votre_site' => 'Se ten&egrave;tz un sit, lo pod&egrave;tz indicar &ccedil;ai sota',
'form_prop_confirmer_envoi' => 'Confirmar lo mandad&iacute;s',
'form_prop_description' => 'Descripcion/comentari',
'form_prop_enregistre' => 'La voastra proposicion es registrada, apareisser&agrave; en linha apr&egrave;s validacion per lu responsables dau sit.',
'form_prop_envoyer' => 'Mandar un messatge',
'form_prop_indiquer_email' => 'Vorgatz indicar una adre&ccedil;a e-mail valida',
'form_prop_indiquer_nom_site' => 'Vorgatz indicar lo nom dau sit.',
'form_prop_indiquer_sujet' => 'Vorgatz indicar un subj&egrave;cte',
'form_prop_message_envoye' => 'Messatge mandat',
'form_prop_nom_site' => 'Nom dau sit',
'form_prop_non_enregistre' => 'La voastra proposicion es pas estada registrada.',
'form_prop_sujet' => 'Subj&egrave;cte',
'form_prop_url_site' => 'Adre&ccedil;a (URL) dau sit',
'forum_acces_refuse' => 'Pod&egrave;tz pas plus accedir en aquelu forums.',
'forum_attention_dix_caracteres' => '<b>D&agrave;ida&nbsp;!</b> lo voastre messatge deu aver au manco d&egrave;tz caract&egrave;rs.',
'forum_attention_trois_caracteres' => '<b>D&agrave;ida&nbsp;!</b> lo voastre titre deu aver au manco tres caract&egrave;rs.',
'forum_attention_trop_caracteres' => '<b>Atencion&nbsp;!</b> lo voastre messatge es tr&ograve;p long (@compte@ caract&egrave;rs)&nbsp;: per si poder registrar, cau pas que passe @max@ caract&egrave;rs.',
'forum_avez_selectionne' => 'Av&egrave;tz seleccionat&nbsp;:',
'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aqu&iacute;</a> per continuar.',
'forum_forum' => 'f&ograve;ro',
'forum_info_modere' => 'Aqueu f&ograve;ro es moderat &agrave; pri&ograve;ri&nbsp;: la voastra contribucion apareisser&agrave; apr&egrave;s &egrave;stre estada validada d\'un administrator dau sit.',
'forum_lien_hyper' => '<b>Ligam ipert&egrave;xt</b> (opcionau)',
'forum_message_definitif' => 'Messatge definitieu: mandar au sit',
'forum_message_trop_long' => 'Lo voastre messatge es tr&ograve;up l&ograve;ng. La talha maximala es de 20000 caract&egrave;rs.',
'forum_ne_repondez_pas' => 'Respondatz pas &agrave;-n-aquel e-mail ma sus lo f&ograve;ro &agrave; l\'adre&ccedil;a seguenta&nbsp;: ',
'forum_non_inscrit' => 'Si&egrave;tz pas inscrich(a), &ograve; l\'adre&ccedil;a &ograve; lo m&ograve;t de santa Clara son erron&egrave;us.',
'forum_page_url' => '(se lo voastre messatge si referisse &agrave; un article publicat sus lo web, &ograve; &agrave; una p&agrave;gina que fornisse mai d\'informacions, podetz marcar &ccedil;ai sota lo titre de la p&agrave;gina e la sieu adre&ccedil;a.)',
'forum_par_auteur' => 'da @auteur@',
'forum_poste_par' => 'Messatge postat @parauteur@ &agrave; la seguida de l\'article &laquo; @titre@ &raquo;.',
'forum_probleme_database' => 'Probl&egrave;ma de basa de donadas, lo voastre messatge es pas estat registrat.',
'forum_qui_etes_vous' => '<b>Cu si&egrave;tz ?</b> (opcionau)',
'forum_texte' => 'T&egrave;xt dau voastre messatge :',
'forum_titre' => 'Titre :',
'forum_titre_erreur' => 'Error...',
'forum_url' => 'URL&nbsp;:',
'forum_valider' => 'Validar aquesta chausida',
'forum_voir_avant' => 'Veire aqueu messatge denant de lo postar',
'forum_votre_email' => 'La voastra adre&ccedil;a e-mail :',
'forum_votre_nom' => 'Lo voastre nom (&ograve; pseudonim)&nbsp;:',
'forum_vous_enregistrer' => 'Per participar &agrave;
  aquest f&ograve;ro, vos dev&egrave;tz registrar d\'en premier. Merc&eacute;
  d\'indicar &ccedil;ai sota l\'identificant personau que vos es
  estat fornit. Se si&egrave;tz pas registrat, dev&egrave;tz',
'forum_vous_inscrire' => 'vos marcar.',

// I
'ical_texte_rss_articles' => 'Lo fichier "backend" dei articles d\'aqu&egrave;u sit si tr&ograve;ba &agrave; l\'adre&ccedil;a&nbsp;:',
'ical_texte_rss_articles2' => 'Pod&egrave;tz tamb&egrave;n obt&eacute;ner de fichiers "backend" per lu articles de cada rubrica dau sit&nbsp;:',
'ical_texte_rss_breves' => 'Existisse de mai un fichier contenent li br&egrave;vas dau sit. En precisar un n&ugrave;mero de rubrica, obtendretz ren que li br&egrave;vas d\'aquela rubrica.',
'icone_a_suivre' => 'Da s&egrave;gre',
'icone_admin_site' => 'Administracion dau sit',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'Ajuda',
'icone_articles' => 'Articles',
'icone_auteurs' => 'Autors',
'icone_breves' => 'Br&egrave;vas',
'icone_brouteur' => 'Navigacion rapida',
'icone_configuration_site' => 'Configuracion',
'icone_configurer_site' => 'Configurar lo voastre sit',
'icone_creer_nouvel_auteur' => 'Crear un noveu autor',
'icone_creer_rubrique' => 'Crear una rubrica',
'icone_creer_sous_rubrique' => 'Crear una sosrubrica',
'icone_deconnecter' => 'Si desconnectar',
'icone_discussions' => 'Discussions',
'icone_doc_rubrique' => 'Documents dei rubricas',
'icone_ecrire_article' => 'Escriure un nov&egrave;l article',
'icone_edition_site' => 'Edicion',
'icone_forum_administrateur' => 'F&ograve;ro dei administrators',
'icone_forum_suivi' => 'Seguit dei f&ograve;ros',
'icone_gestion_langues' => 'Gestion dei lengas',
'icone_informations_personnelles' => 'Informacions personali',
'icone_interface_complet' => 'interfa&ccedil;a completa',
'icone_interface_simple' => 'Interfa&ccedil;a simplificada',
'icone_maintenance_site' => 'Mantenen&ccedil;a dau sit',
'icone_messagerie_personnelle' => 'Messatgeria personala',
'icone_mots_cles' => 'M&ograve;ts claus',
'icone_nouvelle_breve' => 'Escriure una nov&egrave;la br&egrave;va',
'icone_repartition_actuelle' => 'Afichar la reparticion actuala',
'icone_repartition_debut' => 'Afichar la reparticion desp&iacute; lo principi',
'icone_repartition_visites' => 'Desreparticion dei visitas',
'icone_rubriques' => 'Rubricas',
'icone_sauver_site' => 'Sauvagarda dau sit',
'icone_site_entier' => 'Tot lo sit',
'icone_sites_references' => 'Sits referen&ccedil;ats',
'icone_statistiques' => 'Estadisticas dau sit',
'icone_statistiques_visites' => 'Estadisticas',
'icone_suivi_activite' => 'Seguir la vida dau sit',
'icone_suivi_actualite' => 'Evolucion dau&nbsp;sit',
'icone_suivi_forums' => 'S&egrave;gre/gerar lu f&ograve;ros',
'icone_suivi_pettions' => 'Seguir/gerar li peticions',
'icone_suivi_revisions' => 'Modificacions dei articles',
'icone_supprimer_document' => 'Suprimir aqueu document',
'icone_supprimer_image' => 'Suprimir aquel imatge',
'icone_supprimer_message' => 'Suprimir aqueu messatge',
'icone_tous_articles' => 'Toi lu voastres articles',
'icone_tous_auteur' => 'Toi lu autors',
'icone_valider_message' => 'Validar aqueu messatge',
'icone_visiter_site' => 'Visitar',
'icone_voir_en_ligne' => 'Veire en linha',
'image_tourner_180' => 'Rotacion 180&deg;',
'image_tourner_droite' => 'Rotacion 90&deg; &agrave; drecha',
'image_tourner_gauche' => 'Rotacion 90&deg; &agrave; sen&egrave;ca',
'img_indisponible' => 'imatge indisponible',
'impossible' => 'impossible',
'info_a_suivre' => 'DA SEGRE&nbsp;&gt;&gt;',
'info_a_valider' => '[de validar]',
'info_acces_interdit' => 'Acc&egrave;s pro&iuml;bit',
'info_acces_refuse' => 'Acc&egrave;s refudat',
'info_action' => 'Accion: @action@',
'info_administrer_rubriques' => 'Pod&egrave;tz administrar aquela rubrica e li sosrubricas sieui',
'info_adresse_non_indiquee' => 'Av&egrave;tz pas indicat l\'adre&ccedil;a de testar&nbsp;!',
'info_aide' => 'AJUDA:',
'info_ajouter_mot' => 'Ajustar aqueu m&ograve;t',
'info_annonce' => 'ANONCI',
'info_annonces_generales' => 'Anoncis generaus&nbsp;:',
'info_article_propose' => 'Article prepauat',
'info_article_publie' => 'Article publicat',
'info_article_redaction' => 'Article en cors de redaccion',
'info_article_refuse' => 'Article refudat',
'info_article_supprime' => 'Article suprimit',
'info_articles' => 'Articles',
'info_articles_a_valider' => 'Lu articles de validar',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Articles prepauats',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autor(s)',
'info_authentification_ftp' => 'autentificacion (per FTP).',
'info_bloquer_lien' => 'Blocar aquel estac',
'info_breves_02' => 'Br&egrave;vas',
'info_breves_2' => 'br&egrave;vas',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Br&egrave;vas de validar',
'info_connexion_refusee' => 'Connexion refusada',
'info_contact_developpeur' => 'Vorgatz contactar un desvolopaire.',
'info_contenance' => 'Aqueu sit compren&nbsp;:',
'info_contribution' => 'contribucions de f&ograve;ro',
'info_copyright' => 'es un logiciau liure distribuit @lien_gpl@.',
'info_copyright_doc' => 'Per mai d\'informacions, veire lo sit <a href="@spipnet@">http://www.spip.net/oc</a>.',
'info_copyright_gpl' => 'sota licen&ccedil;a GPL',
'info_cours_edition' => 'Lu voastres articles en cors de redacion',
'info_creer_repertoire' => 'Vorgatz crear un fichier &ograve; un repert&ograve;ri nomat',
'info_creer_repertoire_2' => 'en dintre dau sosrepert&ograve;ri <b>@repertoire@</b>, pi:',
'info_creer_vignette' => 'creacion automatica de la vinheta',
'info_deplier' => 'Desplegar',
'info_descriptif_nombre' => 'descriptiu(s):',
'info_description' => 'Descripcion:',
'info_description_2' => 'Descripcion:',
'info_dimension' => 'Dimensions:',
'info_document' => 'Document ',
'info_document_indisponible' => 'Aqueu document es pas disponible',
'info_documents' => 'Documents',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP permete l\'escambi de messatges e la constitucion de f&ograve;ros privats de discucion entre lu participants dau sit. Pod&egrave;tz activar &ograve; desactivar aquela foncionalitat',
'info_ecire_message_prive' => 'Escriure un messatge privat',
'info_email_invalide' => 'Adre&ccedil;a e-mail invalida',
'info_en_cours_validation' => 'Lu voastres articles en cors de redaccion',
'info_en_ligne' => 'A&uuml;ra en linha:',
'info_envoyer_message_prive' => 'Mandar un messatge privat &agrave;-n-aquel autor',
'info_erreur_requete' => 'Error dins la requesta',
'info_erreur_squelette2' => 'Minga d\'esqueleta <b>@fichier@</b> es disponibla...',
'info_erreur_systeme' => 'Error sist&egrave;ma (errno @errsys@)',
'info_erreur_systeme2' => 'Bessai lo disc dur es plen, &ograve; la basa de donadas degalhada. <br />
 <font color=\'red\'>Provatz de <a href=\'@script@\'>reparar la basa</a>,
 &ograve; contactatz lo voastre aubergador.</font>',
'info_fini' => 'Es acabat&nbsp;!',
'info_format_image' => 'Formats d\'imatges que poadon &egrave;stre utilisats per crear de vinhetas: @gd_formats@.',
'info_format_non_defini' => 'format non definit',
'info_grand_ecran' => 'Grand ecran',
'info_image_aide' => 'AJUDA',
'info_image_process_titre' => 'Met&ograve;de de fabricacion dei vinhetas',
'info_impossible_lire_page' => '<b>Error !</b> Impossible de li&egrave;ger la p&agrave;gina <tt><html>@test_proxy@</html></tt> &agrave; trav&egrave;rs lo proxy <tt>',
'info_inclusion_directe' => 'Inclusion dir&egrave;cta&nbsp;:',
'info_inclusion_vignette' => 'Inclusion de la vinheta:',
'info_installation_systeme_publication' => 'Installacion dau sistema de publicacion...',
'info_installer_documents' => 'Pod&egrave;tz installar automaticament toi lu documents contenguts dins lo dorsier @upload@.',
'info_installer_ftp' => 'Coma administrator, pod&egrave;tz installar (per FTP) de fichiers dins lo dorsier @upload@ pi lu seleccionar directament aqu&iacute;.',
'info_installer_images' => 'Pod&egrave;tz installar d\'imatges ai formats JPEG, GIF e PNG.',
'info_installer_images_dossier' => 'Installar d\'imatges dins lo dorsier @upload@ per lu poder seleccionar aqu&iacute;.',
'info_installer_tous_documents' => 'Installar toi lu documents',
'info_interface_complete' => 'interfa&ccedil;a completa',
'info_interface_simple' => 'Interfa&ccedil;a simplificada',
'info_joindre_document_article' => 'Pod&egrave;tz j&oacute;nher &agrave;-n-aquel article de documents de tipe',
'info_joindre_document_rubrique' => 'Pod&egrave;tz j&oacute;nher &agrave;-n-aquela rubrica de documents de tipe',
'info_joindre_documents_article' => 'Pod&egrave;tz j&oacute;nher &agrave;-n-aquel article de documents de tipe&nbsp;:',
'info_l_article' => 'l\'article',
'info_la_breve' => 'la br&egrave;va',
'info_la_rubrique' => 'la rubrica',
'info_langue_principale' => 'Lenga principala dau sit',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ pixels',
'info_les_auteurs_1' => 'per @les_auteurs@ ',
'info_logo_format_interdit' => 'Solets lu l&ograve;gos de formats @formats@ son  autorisats.',
'info_logo_max_poids' => 'Lu l&ograve;gos devon obligat&ograve;riament faire mens de @maxi@ (aqu&egrave;u fichier fa @actuel@).',
'info_logo_max_taille' => 'Lu l&ograve;gos devon obligat&ograve;riament faire mens de @maxi@ (aqu&egrave;u fichier fa @actuel@).',
'info_mail_fournisseur' => 'vos@provesidor.org',
'info_message_2' => 'MESSATGE',
'info_message_supprime' => 'MESSATGE SUPRIMIT',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Data de mesa en linha:',
'info_modification_parametres_securite' => 'modificacions dei param&egrave;tres de seguretat',
'info_mois_courant' => 'En cors de mes:',
'info_mot_cle_ajoute' => 'Lo m&ograve;t clau seguent es estat ajustat &agrave; ',
'info_multi_herit' => 'Lenga predefinida',
'info_multi_langues_soulignees' => 'Li <u>lengas solinhadas</u> benef&iacute;cion d\'una revirada de toi lu t&egrave;xtes de l\'interfa&ccedil;a. Se seleccionatz aqueli lengas, totplen d\'elements dau sit public (datas, formularis) se revirar&agrave;n automaticament. Per li lengas non solinhadas, aquelu elements apareisser&agrave;n dins la lenga principala dau sit.',
'info_multilinguisme' => 'Multileng&uuml;isme',
'info_nom_non_utilisateurs_connectes' => 'Lo voastre nom apareisse pas dins la ti&egrave;ra dei utilisaires connectats.',
'info_nom_utilisateurs_connectes' => 'Lo voastre nom apareisse dins la ti&egrave;ra dei utilisaires connectats.',
'info_nombre_en_ligne' => 'A&uuml;ra en linha&nbsp;:',
'info_non_resultat' => 'Minga de resultat per \\\\\\"@cherche_mot@\\\\\\"',
'info_non_utilisation_messagerie' => 'Utilisetz pas la messatgeria interna d\'aqueu sit.',
'info_nouveau_message' => 'AV&Egrave;TZ UN MESSATGE NOV&Egrave;U',
'info_nouveaux_messages' => 'AV&Egrave;TZ @total_messages@ MESSATGES N&Ograve;US',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Sit sindicat en pana',
'info_pense_bete' => 'N&Ograve;TA DE RENEMBRAN&Ccedil;A ',
'info_petit_ecran' => 'Pichon ecran',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'pix&egrave;us',
'info_plusieurs_mots_trouves' => 'Mantun m&ograve;ts claus trobats per "@cherche_mot@":',
'info_popularite_5' => 'popularitat:',
'info_portfolio' => 'Poartfolio',
'info_portfolio_automatique' => 'Poartf&ograve;lio automatic:',
'info_premier_resultat' => '[@debut_limit@ promiers resultats de @total@]',
'info_premier_resultat_sur' => ' [@debut_limit@ promiers resultats de @total@]',
'info_probleme_grave' => 'probl&egrave;ma de',
'info_propose_1' => '[@nom_site_spip@] Prepaua: @titre@',
'info_propose_2' => 'Article prepauat
----------------',
'info_propose_3' => 'L\'article "@titre@" es prepauat &agrave; la publicacion.',
'info_propose_4' => 'Si&egrave;tz convidat &agrave; lo venir consultar e &agrave; donar la voastra opinion',
'info_propose_5' => 'dins lo f&ograve;ro que li es estacat. Es disponibla &agrave; l\'adre&ccedil;a:',
'info_publie_01' => 'L\'article "@titre@" es estat validat per @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLICA: @titre@',
'info_publie_2' => 'Article publicat
----------------',
'info_rechercher' => 'Recercar',
'info_rechercher_02' => 'Recercar:',
'info_remplacer_vignette' => 'Rempla&ccedil;ar la vinheta predefinida per un l&ograve;go personalisat&nbsp;:',
'info_retablir_lien' => 'Tornar establir aquel estac',
'info_retirer_mot' => 'Traire aqueu m&ograve;t',
'info_retirer_mots' => 'Traire toi lu m&ograve;ts',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'sensa titre',
'info_selectionner_fichier' => 'Pod&egrave;tz seleccionar un fichier dau dorsier @upload@',
'info_selectionner_fichier_2' => 'Seleccionar un fichier&nbsp;:',
'info_signature_supprimee' => 'Signatura suprimida',
'info_signature_supprimee_erreur' => 'Error&nbsp;: aqu&egrave;u c&ograve;de de supression correspoande &agrave; minga signatura',
'info_site_attente' => 'Sit web en asp&egrave;ra de validacion',
'info_site_reference' => 'Sit referen&ccedil;at en linha',
'info_site_refuse' => 'Sit web refudat',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Referen&ccedil;ar un sit',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'suprimir la vinheta',
'info_symbole_bleu' => 'Lo simb&ograve;l <b>blu</b> marca una <b>n&ograve;ta de remembran&ccedil;a</b>: es &agrave; dire un messatge dau voastre usatge personau.',
'info_symbole_jaune' => 'Lo simb&ograve;l <b>jaune</b> marca un <b>anonci per toi lu redactors </b>: lu administrators la poadon modificar, cada redactor la p&ograve;u veire.',
'info_symbole_vert' => 'Lo simb&ograve;l <b>verd</b> marca lu <b>messatges escambiats m&eacute; d\'autres utilisaires</b> dau sit.',
'info_syndication' => 'sindicacion:',
'info_syndication_articles' => 'article(s)',
'info_telecharger' => 'Telecargar desp&iacute; lo voastre ordinator&nbsp;:',
'info_telecharger_nouveau_logo' => 'Telecargar un nov&egrave;u l&ograve;go&nbsp;:',
'info_telecharger_ordinateur' => 'Telecargar desp&iacute; lo voastre ordinator&nbsp;:',
'info_tous_resultats_enregistres' => '[toi lu resultats son registrats]',
'info_tout_afficher' => 'Far par&eacute;isser tot',
'info_travaux_texte' => 'Aqueu sit es pas encara configurat. Tornatz plus tard...',
'info_travaux_titre' => 'Sit en &ograve;bras',
'info_trop_resultat' => 'Tr&ograve;p de resultats per \\\\\\&quot;@cherche_mot@\\\\\\&quot;; vorgatz afinar la recerca.',
'info_utilisation_messagerie_interne' => 'Utilisatz la messatgeria interna d\'aqueu sit.',
'info_valider_lien' => 'validar aquel estac',
'info_verifier_image' => ', vorgatz verificar que lu voastres imatges son estats transferits correctament.',
'info_vignette_defaut' => 'Vinheta predefinida',
'info_vignette_personnalisee' => 'Vinheta personalisada',
'info_visite' => 'visita:',
'info_visites' => 'visitas:',
'info_vos_rendez_vous' => 'Lu voastres rend&egrave;tz-vos &agrave; venir',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Li voastri n&ograve;tas de renembran&ccedil;a ',
'item_breve_proposee' => 'Br&egrave;va prepauada',

// L
'lien_afficher_icones_seuls' => 'Far par&eacute;isser li ic&ograve;nas unicament',
'lien_afficher_texte_icones' => 'Far par&eacute;isser li ic&ograve;nas e lo t&egrave;xt',
'lien_afficher_texte_seul' => 'Far par&eacute;isser lo t&egrave;xt solet',
'lien_liberer' => 'liberar',
'lien_liberer_tous' => 'liberatz aquelu articles',
'lien_nouvea_pense_bete' => 'NOV&Egrave;LA N&Ograve;TA DE RENEMBRAN&Ccedil;A ',
'lien_nouveau_message' => 'MESSATGE NOV&Egrave;U',
'lien_nouvelle_annonce' => 'ANONCI NOV&Egrave;U',
'lien_petitions' => 'PETICION',
'lien_popularite' => 'popularitat: @popularite@%',
'lien_racine_site' => 'RAI&Ccedil; DAU SIT',
'lien_reessayer' => 'tornar temptar',
'lien_repondre_message' => 'Respoandre &agrave;-n-aqueu messatge',
'lien_supprimer' => 'suprimir',
'lien_tout_afficher' => 'Far tot par&eacute;isser',
'lien_visite_site' => 'visitar aqueu sit',
'lien_visites' => '@visites@&nbsp;visitas',
'lien_voir_auteur' => 'Veire aquel autor',
'ligne' => 'Linha',
'login' => 'Connexion',
'login_acces_prive' => 'acc&egrave;s &agrave; l\'espaci privat',
'login_autre_identifiant' => 'si connectar emb\'un autre identificant',
'login_cookie_accepte' => 'Vorgatz configurar lo voastre navigador per que lu acc&egrave;pte (aumens per aqueu sit).',
'login_cookie_oblige' => 'Per vos identificar d\'una maniera segura sus aquest sit, vos cau acceptar lu cookies.',
'login_deconnexion_ok' => 'Si&egrave;tz desconnectat/ada.',
'login_erreur_pass' => 'Error de m&ograve;t de santa Clara.',
'login_espace_prive' => 'espaci privat',
'login_identifiant_inconnu' => 'L\'identificant &laquo; @login@ &raquo; es desconoissut.',
'login_login' => 'Login :',
'login_login2' => 'Login (identificant de connexion au sit)&nbsp;:',
'login_login_pass_incorrect' => '(Login &ograve; m&ograve;t de santa Clara incorret.)',
'login_motpasseoublie' => 'm&ograve;t&nbsp;de&nbsp;Santa&nbsp;Clara&nbsp;oblidat&nbsp;?',
'login_non_securise' => 'M&egrave;fi, qu\'aqueu formulari es pas securisat.
   Se vol&egrave;tz pas que lo voastre m&ograve;t de santa Clara sigue
   interceptat sus la ret, vorgatz activar Javascript 
   dins lo voastre navigador e',
'login_nouvelle_tentative' => 'nov&egrave;la temptativa',
'login_par_ici' => 'Si&egrave;tz registrat... per aqu&iacute;...',
'login_pass2' => 'M&ograve;t de santa Clara&nbsp;:',
'login_preferez_refuser' => '<b>Se preferiss&egrave;tz refudar lu cookies</b>, un autre met&ograve;de de connexion (mens securisat) es &agrave; la voastra disposicion:',
'login_recharger' => 'Tornar cargar aquela p&agrave;gina',
'login_rester_identifie' => 'Demorar identificat quaucu jorns',
'login_retour_public' => 'Tornar au sit public',
'login_retour_site' => 'Tornar au sit public',
'login_retoursitepublic' => 'tornar&nbsp;au&nbsp;sit&nbsp;public',
'login_sans_cookiie' => 'Identificacion sensa cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 's\'inscriure',
'login_test_navigateur' => 'test navigador/tornar&nbsp;connectar',
'login_verifiez_navigateur' => '(verificatz pura que lo voastre navigador a pas conservat lo m&ograve;t de santa Clara en mem&ograve;ria...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'Escondre li reviradas',
'module_fichiers_langues' => 'Fichiers de langa',

// N
'navigateur_pas_redirige' => 'Se lo voastre navigador es pas redirigit, clicatz aqu&iacute; per continuar.',
'numero' => 'Numer&ograve;',

// O
'occurence' => 'Ocurr&eacute;n&ccedil;a',
'onglet_affacer_base' => 'Escafar la basa',
'onglet_auteur' => 'L\'autor',
'onglet_contenu_site' => 'Contengut dau sit',
'onglet_evolution_visite_mod' => 'Evolucion',
'onglet_fonctions_avances' => 'Foncions avan&ccedil;adas',
'onglet_informations_personnelles' => 'Informacions personali',
'onglet_interactivite' => 'Interactivitat',
'onglet_messagerie' => 'Messatgeria',
'onglet_messages_internes' => 'Messatges internes',
'onglet_messages_publics' => 'Messatges publics',
'onglet_messages_vide' => 'Messatges sensa t&egrave;xt',
'onglet_origine_visites' => 'Origina dei visitas',
'onglet_repartition_debut' => 'desp&iacute; lo principi',
'onglet_repartition_lang' => 'Reparticion per lengas',
'onglet_repartition_rubrique' => 'Reparticion per rubricas',
'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
'onglet_vider_cache' => 'Vuar l\'amagador',
'ortho_trop_de_fautes2' => 'Comen&ccedil;atz per corregir li errors mai evidenti e tornatz assajar pu&egrave;i.',

// P
'pass_choix_pass' => 'Vorgatz chausir lo voastre nov&egrave;u m&ograve;t de santa Clara&nbsp;:',
'pass_erreur' => 'Error',
'pass_erreur_acces_refuse' => '<b>Error :</b> pod&egrave;tz plus accedir &agrave;-n-aqueu sit.',
'pass_erreur_code_inconnu' => '<b>Error :</b> aqueu c&ograve;de correspoande &agrave; minga de visitaires qu\'an acc&egrave;s &agrave;-n-aqueu sit.',
'pass_erreur_non_enregistre' => '<b>Error :</b> l\'adre&ccedil;a <tt>@email_oubli@</tt> es pas registrada sus aqueu sit.',
'pass_erreur_non_valide' => '<b>Error :</b> aquel e-mail <tt>@email_oubli@</tt> es pas valid !',
'pass_erreur_probleme_technique' => '<b>Error:</b> per l\'encausa d\'un problema tecnic, l\'e-mail si p&ograve;u pas mandar. ',
'pass_espace_prive_bla' => 'L\'espaci privat d\'aquest sit es dub&egrave;rt ai
  visitaires que si son inscrichs. Un c&ograve;up registrat/ada,
  podr&egrave;tz consultar lu articles en cors de redaccion,
  prepauar d\'articles nov&egrave;us e participar &agrave; toi lu f&ograve;ros.',
'pass_forum_bla' => 'Av&egrave;tz demandat d\'intervenir dins un f&ograve;ro
  reservat ai visitaires registrats.',
'pass_indiquez_cidessous' => 'Marcatz &ccedil;ai sota l\'adre&ccedil;a e-mail dont
 vos registreretz lo c&ograve;up passat.
   Receberetz un e-mail que vos balhar&agrave; lo biais de
    tornar trobar lo voastre acc&egrave;s.',
'pass_mail_passcookie' => '(aqu&ograve; es un messatge automatic)
Per tornar trobar lo voastre acc&egrave;s au sit
@nom_site_spip@ (@adresse_site@)

Vorgatz anar &agrave; l\'adre&ccedil;a seguenta:

    @sendcookie@

Podretz intrar un m&ograve;t de santa Clara nov&egrave;u
e vos tornar connectar au sit.

',
'pass_mot_oublie' => 'M&ograve;t de santa Clara oblidat',
'pass_nouveau_enregistre' => 'Lo voastre nov&egrave;u m&ograve;t de santa Clara es estat registrat.',
'pass_nouveau_pass' => 'M&ograve;t de santa Clara nov&egrave;u',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Denembran&ccedil;a dau m&ograve;t de santa Clara',
'pass_quitter_fenetre' => 'Quitar aquesta fen&egrave;stra ',
'pass_rappel_login' => 'Renembran&ccedil;a: lo voastre identificant (login) es &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Receberetz un e-mail que vos explicar&agrave; coma tornar trobar lo voastre acc&egrave;s au sit.',
'pass_retour_public' => 'Tornar au sit public',
'pass_rien_a_faire_ici' => 'Ren &agrave; faire aqu&iacute;.',
'pass_vousinscrire' => 'S\'inscriure sus aquest sit',
'precedent' => 'precedent',
'previsualisation' => 'Previsualisacion',
'previsualiser' => 'Previsualisar',

// R
'retour' => 'Tornar',

// S
'spip_conforme_dtd' => 'SPIP consid&egrave;ra aqueu document coma conf&ograve;rm au sieu DOCTYPE :',
'squelette' => 'esqueleta',
'squelette_inclus_ligne' => 'esqueleta inclusa, linha',
'squelette_ligne' => 'esqueleta, linha',
'stats_visites_et_popularite' => '@visites@ visitas&nbsp;; popularitat&nbsp;: @popularite@',
'suivant' => 'seguent',

// T
'taille_ko' => '@taille@&nbsp;Ko',
'taille_mo' => '@taille@&nbsp;Mo',
'taille_octets' => '@taille@&nbsp;octets',
'texte_actualite_site_1' => 'Quora seretz familharisat/ada m&eacute; l\'interfa&ccedil;a, podretz clicar sus &laquo;',
'texte_actualite_site_2' => 'interfa&ccedil;a completa',
'texte_actualite_site_3' => '&raquo; per aver mai de possibilitats.',
'texte_creation_automatique_vignette' => 'La creacion automatica de vinhetas de previsualisacion es activada sus aqueu sit. S\'installatz &agrave; partir d\'aqueu formulari d\'imatges au(ai) format(s) @gd_formats@, ser&agrave;n acompanhats d\'una vinheta d\'una talha maximala de @taille_preview@ pix&egrave;ls.',
'texte_documents_associes' => 'Lu documents seguents son associats &agrave; l\'article, ma son pas estats drech inserits. Segon la compaginacion dau sit public, podr&agrave;n apar&eacute;isser sota forma de documents jonchs.',
'texte_erreur_mise_niveau_base' => 'Error de basa de donadas pendent la mesa &agrave; niv&egrave;u. L\'imatge <b>@fichier@</b> es pas passat (article @id_article@).
  Notatz ben aquela referen&ccedil;a, tornatz ensajar la mesa &agrave; niv&egrave;u, e verificatz pi que lu imatges apar&eacute;isson encara dins lu articles.',
'texte_erreur_visiteur' => 'Av&egrave;tz provat d\'acc&egrave;dre &agrave; l\'espaci privat m\'un identificant que lo permete pas.',
'texte_inc_auth_1' => 'Si&egrave;tz identificat/ada coma
   <b>@auth_login@</b>, ma aqueu login existisse pas &ograve; pas plus mai dins la basa.
  Temptatz de vos',
'texte_inc_auth_2' => 'tornar connectar',
'texte_inc_auth_3' => ', apr&egrave;s aver eventualament quitat pi
  tornat lan&ccedil;ar lo voastre navigador.',
'texte_inc_config' => 'Li modificacions fachi dins aquesti p&agrave;ginas influen&ccedil;an bravament lo
 foncionament dau voastre sit. Vos aconselham de pas i intervenir tant que si&egrave;tz pas
 acostumat/ada au foncionament dau sistema SPIP. <br /><br /><b>
 En generau, si conselha foart
 de laissar la carga d\'aquesti p&agrave;ginas au webm&egrave;stre principau dau voastre sit.</b>',
'texte_inc_meta_1' => 'Lo sist&egrave;ma a rescontrat un error dins l\'escritura dau fichier <code>@fichier@</code>. Vorgatz, coma administrator/triz dau sit,',
'texte_inc_meta_2' => 'verificar lu drechs d\'escritura',
'texte_inc_meta_3' => 'sus lo repert&ograve;ri <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'en cors de redaccion',
'texte_statut_poubelle' => 'au bordilhier',
'texte_statut_propose_evaluation' => 'prepauat per evaluacion',
'texte_statut_publie' => 'publicat en linha',
'texte_statut_refuse' => 'refudat',
'titre_ajouter_mot_cle' => 'AJUSTAR UN M&Ograve;T CLAU :',
'titre_breve_proposee' => 'Breva prepauada',
'titre_breve_publiee' => 'Breva publicada',
'titre_breve_refusee' => 'Br&egrave;va refudada',
'titre_cadre_raccourcis' => 'ESCORCHAS :',
'titre_changer_couleur_interface' => 'Cambiar la color de l\'interfa&ccedil;a',
'titre_forum' => 'F&ograve;ro',
'titre_image_admin_article' => 'Podetz administrar aquel article',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'D\'ajuda sus aquel element',
'titre_image_auteur_supprime' => 'Autor suprimit',
'titre_image_redacteur' => 'Redactor sensa acc&egrave;s',
'titre_image_redacteur_02' => 'Redactor',
'titre_image_visiteur' => 'Visitaire',
'titre_joindre_document' => 'J&Oacute;NHER UN DOCUMENT',
'titre_liens_entrants' => 'Estacs intrants',
'titre_mots_cles' => 'M&Ograve;TS CLAUS',
'titre_probleme_technique' => 'Atencion&nbsp;: un problema tecnic (servidor SQL) empacha d\'accedir &agrave;-n-aquela part dau sit. Merc&eacute; de la voastra indulgen&ccedil;a.',
'titre_publier_document' => 'PUBLICAR UN DOCUMENT DINS AQUELA RUBRICA',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Estatisticas dau sit',
'titre_titre_document' => 'Titre dau document&nbsp;:',
'todo' => 'De venir',
'trad_reference' => '(article de referen&ccedil;a)',

// Z
'zbug_balise_b_aval' => '&nbsp;: balisa B en aval',
'zbug_balise_inexistante' => 'Balisa @balise@ mau declarada per @from@ ',
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'bloca',
'zbug_boucle_recursive_undef' => 'bloca recursiva non definida',
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Camp @champ@ f&ograve;ra bloca',
'zbug_champ_hors_motif' => 'Camp @champ@ en def&ograve;ra d\'una bloca de motiu @motif@',
'zbug_code' => 'c&ograve;de',
'zbug_critere_inconnu' => 'crit&egrave;ri esconoissut @critere@',
'zbug_distant_interdit' => 'ext&egrave;rne pro&iuml;bit',
'zbug_doublon_table_sans_cle_primaire' => 'doblons sus una taula sensa clau primari atomica',
'zbug_doublon_table_sans_index' => 'doblons sus una taula sensa ind&egrave;x',
'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla',
'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrador manca',
'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorr&egrave;cta',
'zbug_erreur_compilation' => 'Error de compilacion',
'zbug_erreur_execution_page' => 'error d\'execucion de la p&agrave;gina',
'zbug_erreur_filtre' => 'Error: filtre <b>&laquo; @filtre@ &raquo;</b> non definit',
'zbug_erreur_meme_parent' => '{meme_parent} s\'aplica unicament ai blocas (FORUMS) &ograve; (RUBRIQUES)',
'zbug_erreur_squelette' => 'Error(s) dins l\'esqueleta',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => 'Error sobre lo sit',
'zbug_inversion_ordre_inexistant' => 'inversion d\'un &ograve;rdre inexistent',
'zbug_pagination_sans_critere' => 'Balisa #PAGINATION sensa crit&egrave;ri {pagination} &ograve; emplegada dins una bocla recursiva',
'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorr&egrave;ctes',
'zbug_profile' => 'Temps de calcul&nbsp;: @time@',
'zbug_resultat' => 'resultat',
'zbug_serveur_indefini' => 'servidor SQL endefinit',
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Taula SQL &laquo; @table@ &raquo; esconoissuda',
'zxml_connus_attributs' => 'atributs conoissuts',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'atribut pas conoissut',
'zxml_inconnu_balise' => 'balisa pas conoissuda',
'zxml_inconnu_entite' => 'entitat pas conoissuda',
'zxml_inconnu_id' => 'ID pas conoissut',
'zxml_mais_de' => 'ma de',
'zxml_non_conforme' => 'es pas conf&ograve;rm au motiu',
'zxml_non_fils' => 'es pas un enfant de',
'zxml_nonvide_balise' => 'balisa non vu&egrave;ia',
'zxml_obligatoire_attribut' => 'atribut obligat&ograve;ri ma absent dins',
'zxml_succession_fils_incorrecte' => 'succession dei enfants incorr&egrave;cte',
'zxml_survoler' => 'susvolar per veire lu corr&egrave;ctes',
'zxml_valeur_attribut' => 'valor de l\'atribut',
'zxml_vide_balise' => 'balise vu&egrave;ia',
'zxml_vu' => 'vist ad&eacute;s'
);

?>
